@@ -54,9 +54,6 @@ It consists of the following submodules:
 
 from .version import __version__
 
-import numpy as np
-np.seterr(divide='ignore', invalid='ignore')
-
 from . import utils
 from .utils import Workspace, Project
 from . import core
